==> imixs-workflow-engine-6.0.1-sources.jar: org/imixs/workflow/engine/plugins/AccessPlugin.java <==
/*******************************************************************************
 *  Imixs Workflow 
 *  Copyright (C) 2001, 2011 Imixs Software Solutions GmbH,  
 *  http://www.imixs.com
 *  
 *  This program is free software; you can redistribute it and/or 
 *  modify it under the terms of the GNU General Public License 
 *  as published by the Free Software Foundation; either version 2 
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 *  General Public License for more details.
 *  
 *  You can receive a copy of the GNU General Public
 *  License at http://www.gnu.org/licenses/gpl.html
 *  
 *  Project: 
 *  	http://www.imixs.org
 *  	http://java.net/projects/imixs-workflow
 *  
 *  Contributors:  
 *  	Imixs Software Solutions GmbH - initial API and implementation
 *  	Ralph Soika - Software Developer
 *******************************************************************************/

package org.imixs.workflow.engine.plugins;

import java.util.logging.Logger;

import org.imixs.workflow.ItemCollection;
import org.imixs.workflow.exceptions.PluginException;

/**
 * Deprecated - see PaticipantAdapter.
 * 
 * @author Ralph Soika
 * @version 3.0
 * @see org.imixs.workflow.WorkflowManager
 */
@Deprecated
public class AccessPlugin extends AbstractPlugin {
    private static Logger logger = Logger.getLogger(AccessPlugin.class.getName());

    @Deprecated
    public ItemCollection run(ItemCollection adocumentContext, ItemCollection documentActivity) throws PluginException {

        logger.warning("The AccessPlugin is deprecated and can be removed from this model!");
        return adocumentContext;
    }

}

==> imixs-workflow-engine-6.0.8-sources.jar: org/imixs/workflow/engine/plugins/AccessPlugin.java <==
/*******************************************************************************
 *  Imixs Workflow 
 *  Copyright (C) 2001, 2011 Imixs Software Solutions GmbH,  
 *  http://www.imixs.com
 *  
 *  This program is free software; you can redistribute it and/or 
 *  modify it under the terms of the GNU General Public License 
 *  as published by the Free Software Foundation; either version 2 
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 *  General Public License for more details.
 *  
 *  You can receive a copy of the GNU General Public
 *  License at http://www.gnu.org/licenses/gpl.html
 *  
 *  Project: 
 *  	http://www.imixs.org
 *  	http://java.net/projects/imixs-workflow
 *  
 *  Contributors:  
 *  	Imixs Software Solutions GmbH - initial API and implementation
 *  	Ralph Soika - Software Developer
 *******************************************************************************/

package org.imixs.workflow.engine.plugins;

import java.util.logging.Logger;

import org.imixs.workflow.ItemCollection;
import org.imixs.workflow.exceptions.PluginException;

/**
 * Deprecated - see PaticipantAdapter.
 * 
 * @author Ralph Soika
 * @version 3.0
 * @see org.imixs.workflow.WorkflowManager
 */
@Deprecated
public class AccessPlugin extends AbstractPlugin {
    private static final Logger logger = Logger.getLogger(AccessPlugin.class.getName());

    @Deprecated
    public ItemCollection run(ItemCollection adocumentContext, ItemCollection documentActivity) throws PluginException {

        logger.warning("The AccessPlugin is deprecated and can be removed from this model!");
        return adocumentContext;
    }

}
